==> uix-kit-3.2.0.tgz: package/src/components/ES5/back-to-top/js/back-to-top.js <==
/* 
 *************************************
 * <!-- Back to Top -->
 *************************************
 */
APP = ( function ( APP, $, window, document ) {
    'use strict';
	
    APP.BACK_TO_TOP               = APP.BACK_TO_TOP || {};
	APP.BACK_TO_TOP.version       = '0.0.3';
    APP.BACK_TO_TOP.documentReady = function( $ ) {

		
		var $window      = $( window ),
			windowWidth  = window.innerWidth,
			windowHeight = window.innerHeight;
		
		$( '<a href="#" id="uix-to-top"><i class="fa fa-arrow-up" aria-hidden="true"></i></a>' ).appendTo( 'body' );
		$.when( $( '#uix-to-top' ).length > 0).then( function() {
			
			//-------- Sticky button of back to top 
			//Note: Don't use Waypoint, because the Offset is wrong on calculating height of fixed element
			var $el = $( '#uix-to-top' )
			
			$window.on('scroll touchmove', function() {

				var scrollTop = $( this ).scrollTop(),
					spyTop    = windowHeight/2;


				if ( scrollTop >= spyTop ) {
					$el.addClass( 'active' );
				} else {
					$el.removeClass( 'active' );	
				}

			});

			

			//-------- Click event of back button
			$el.on( 'click', function( e ) {
				e.preventDefault();

				TweenMax.to( window, 0.5, {
					scrollTo: {
						y        : 0, //y: "max" --> vertical scroll to bottom
						autoKill : false
					},
					ease: Power2.easeOut
				});	


			});	
	
			
		});
		
	
		
		
    };

    APP.components.documentReady.push( APP.BACK_TO_TOP.documentReady );
    return APP;

}( APP, jQuery, window, document ) );

==> uix-kit-3.4.6.tgz: package/src/components/ES5/back-to-top/js/back-to-top.js <==
/* 
 *************************************
 * <!-- Back to Top -->
 *************************************
 */
APP = ( function ( APP, $, window, document ) {
    'use strict';
	
    APP.BACK_TO_TOP               = APP.BACK_TO_TOP || {};
	APP.BACK_TO_TOP.version       = '0.0.3';
    APP.BACK_TO_TOP.documentReady = function( $ ) {

		
		var $window      = $( window ),
			windowWidth  = window.innerWidth,
			windowHeight = window.innerHeight;
		
		$( '<a href="#" id="uix-to-top"><i class="fa fa-arrow-up" aria-hidden="true"></i></a>' ).appendTo( 'body' );
		$.when( $( '#uix-to-top' ).length > 0).then( function() {
			
			//-------- Sticky button of back to top 
			//Note: Don't use Waypoint, because the Offset is wrong on calculating height of fixed element
			var $el = $( '#uix-to-top' );
			
			$window.on('scroll touchmove', function() {

				var scrollTop = $( this ).scrollTop(),
					spyTop    = windowHeight/2;


				if ( scrollTop >= spyTop ) {
					$el.addClass( 'active' );
				} else {
					$el.removeClass( 'active' );	
				}

			});

			

			//-------- Click event of back button
			$el.on( 'click', function( e ) {
				e.preventDefault();

				TweenMax.to( window, 0.5, {
					scrollTo: {
						y        : 0, //y: "max" --> vertical scroll to bottom
						autoKill : false
					},
					ease: Power2.easeOut
				});	
				
				return false;


			});	
	
			
		});
		
	
		
		
    };

    APP.components.documentReady.push( APP.BACK_TO_TOP.documentReady );
    return APP;

}( APP, jQuery, window, document ) );
